==> AxolotlClient-Waypoints-0.0.1%2B3.1.5%2B1.21.1-sources.jar: io/github/axolotlclient/waypoints/mixin/GuiMixin.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient (Waypoints Mod).
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.waypoints.mixin;

import io.github.axolotlclient.waypoints.AxolotlClientWaypoints;
import net.minecraft.class_310;
import net.minecraft.class_329;
import net.minecraft.class_332;
import net.minecraft.class_9779;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_329.class)
public class GuiMixin {


	@Inject(method = "<init>", at = @At("TAIL"))
	private void register(class_310 minecraft, CallbackInfo ci) {
		AxolotlClientWaypoints.MINIMAP.setup();
	}

	@Inject(method = "tick()V", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/player/Inventory;getSelected()Lnet/minecraft/world/item/ItemStack;"))
	private void updateMinimap(CallbackInfo ci) {
		AxolotlClientWaypoints.MINIMAP.updateMapView();
	}

	@Inject(method = "renderCameraOverlays", at = @At("TAIL"))
	private void renderHud(class_332 guiGraphics, class_9779 deltaTracker, CallbackInfo ci) {
		AxolotlClientWaypoints.WAYPOINT_RENDERER.renderWaypoints(guiGraphics, deltaTracker);
		AxolotlClientWaypoints.MINIMAP.renderMapOverlay(guiGraphics, deltaTracker);
	}
}

==> AxolotlClient-Waypoints-0.0.2%2B3.1.8%2B1.20.1-sources.jar: io/github/axolotlclient/waypoints/mixin/GuiMixin.java <==
/*
 * Copyright © 2025 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient (Waypoints Mod).
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.waypoints.mixin;

import io.github.axolotlclient.waypoints.AxolotlClientWaypoints;
import net.minecraft.class_310;
import net.minecraft.class_329;
import net.minecraft.class_332;
import net.minecraft.class_918;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_329.class)
public class GuiMixin {


	@Inject(method = "<init>", at = @At("TAIL"))
	private void register(class_310 minecraft, class_918 itemRenderer, CallbackInfo ci) {
		AxolotlClientWaypoints.MINIMAP.setup();
	}

	@Inject(method = "tick()V", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/entity/player/Inventory;getSelected()Lnet/minecraft/world/item/ItemStack;"))
	private void updateMinimap(CallbackInfo ci) {
		AxolotlClientWaypoints.MINIMAP.updateMapView();
	}

	@Inject(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/Minecraft;getDeltaFrameTime()F"))
	private void renderHud(class_332 guiGraphics, float delta, CallbackInfo ci) {
		AxolotlClientWaypoints.WAYPOINT_RENDERER.renderWaypoints(guiGraphics, delta);
		AxolotlClientWaypoints.MINIMAP.renderMapOverlay(guiGraphics, delta);
	}
}
